 /**
  * Semplice Calendario
  *
  * @version 14-Ott-2007
  * @author Adriano Luchetta
  *
  * Classe che rappresenta un calendario
  *
  */
import java.util.Calendar;
import java.util.Scanner;
public class Calendario
{
   private int anno;
   private int mese;
   private int giorno;
   private Calendar currentCalendar;
   private Calendar calendar;
   
   /**
      inizializza il calendario con la data passata come parametro esplicito. La data deve essere nel formato gg/mm/aaaa

      @param in la data a cui il calendario e' inizializzato
   */
   public Calendario(String in)
   {
      currentCalendar = Calendar.getInstance();
      calendar = Calendar.getInstance();

      Scanner tok = new Scanner(in);
      tok.useDelimiter("[/:-]+");

      try {
      giorno = Integer.parseInt(tok.next());
      mese = Integer.parseInt(tok.next());
      anno = Integer.parseInt(tok.next());
      }
      catch (NumberFormatException e)
      {
         System.out.println(in + ": data errata");
         System.exit(0);
      }
      
      //System.out.println("giorno = " + giorno + " mese = " + mese + " anno = " + anno);
      
      if (!isCorrectDate(anno, mese, giorno))
      {
         System.out.println(in + ": data errata");
         System.exit(0);
      }

      calendar.set(anno, mese - 1, giorno);
      
      //System.out.println("calendar: " + calendar);
      //System.out.println("currentCalendar: " + currentCalendar);
      tok.close();
   }

   /**
      calcola il giorno della settimana
      @return il giorno della settimana: Domenica Lunedi' Martedi' Mercoledi' Giovedi' Venerdi' Sabato
   */
   public String giornoDellaSettimana()
   {
      final String[] GIORNO_SETTIMANA = { "", "Domenica", "Lunedi'", "Martedi'", "Mercoledi'", "Giovedi'", "Venerdi'", "Sabato"};
      return GIORNO_SETTIMANA[calendar.get(Calendar.DAY_OF_WEEK)];
   }
   
   /**
      calcola i giorni trascorsi alla data odierna
      @return i giorni trascorsi
   */
   public int giorniDa()
   {
      final long MILLIS_IN_SECOND = 1000;
      final int SECONDS_IN_MINUTE = 60;
      final int MINUTES_IN_HOUR = 60;
      final int HOUR_IN_DAY = 24;

      final long MILLIS_IN_GIORNO = MILLIS_IN_SECOND * SECONDS_IN_MINUTE * MINUTES_IN_HOUR * HOUR_IN_DAY;
      long millisOggi = currentCalendar.getTimeInMillis();
      long millisAllaData = calendar.getTimeInMillis();
      return (int)((millisOggi - millisAllaData) / MILLIS_IN_GIORNO);
   }
   
   private boolean isCorrectDate(int anno, int mese, int giorno)
   {
      int[] giorniPerMese = {31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };

      if (anno < 1970)
         return false;
      
      if (mese < 0 || mese > 12)
         return false;
         
      if (giorno < 0 || giorno > giorniPerMese[mese - 1])
         return false;
         
      if (giorno == 29 && !isLeapYear(anno))
         return false;
         
      return true;
   }
   
   private boolean isLeapYear(int n)
   {
      if (n % 4 != 0)
         return false;
         
      if ((n % 100 == 0) && (n % 400 != 0))
         return false;
         
      return true;
   }
}